==> ironic-inspector-2.0.0.tar.gz: ironic-inspector-2.0.0/ironic_inspector/plugins/example.py <==
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Example plugin."""

import logging

from ironic_inspector.plugins import base


LOG = logging.getLogger('ironic_inspector.plugins.example')


class ExampleProcessingHook(base.ProcessingHook):  # pragma: no cover
    def before_processing(self, introspection_data, **kwargs):
        LOG.debug('before_processing: %s', introspection_data)

    def before_update(self, introspection_data, node_info, node_patches,
                      ports_patches, **kwargs):
        LOG.debug('before_update: %s (node %s)', introspection_data,
                  node_info.uuid)


def example_not_found_hook(self, introspection_data):
    """Hook to run when the node cache query returns not found.

    :param node_info: raw information sent by the ramdisk, shouldn't be
                      modified by this hook.
    :returns: NodeInfo object representing a newly cached node
              object or None
    """
    LOG.debug('Processing node not found %s', introspection_data)

==> ironic-inspector-3.0.0.tar.gz: ironic-inspector-3.0.0/ironic_inspector/plugins/example.py <==
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Example plugin."""

from oslo_log import log

from ironic_inspector.plugins import base


LOG = log.getLogger('ironic_inspector.plugins.example')


class ExampleProcessingHook(base.ProcessingHook):  # pragma: no cover
    def before_processing(self, introspection_data, **kwargs):
        LOG.debug('before_processing: %s', introspection_data)

    def before_update(self, introspection_data, node_info, **kwargs):
        LOG.debug('before_update: %s (node %s)', introspection_data,
                  node_info.uuid)


def example_not_found_hook(introspection_data, **kwargs):
    LOG.debug('Processing node not found %s', introspection_data)


class ExampleRuleAction(base.RuleActionPlugin):  # pragma: no cover
    def apply(self, node_info, params, **kwargs):
        LOG.debug('apply action to %s: %s', node_info.uuid, params)

    def rollback(self, node_info, params, **kwargs):
        LOG.debug('rollback action to %s: %s', node_info.uuid, params)
